DoxModel class

Constructors

DoxModel({String? table, String primaryKey = 'id', String createdAt = 'created_at', String updatedAt = 'updated_at', bool softDelete = false})
const

Properties

createdAt → String
final
hashCode → int
The hash code for this object.
no setterinherited
primaryKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softDelete → bool
final
table → String?
final
updatedAt → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited